@@ -8,8 +8,8 @@ from bo4e.enum.marktrolle import Marktrolle
 from bo4e.enum.rollencodetyp import Rollencodetyp
 
 
-@attr.s(auto_attribs=True, kw_only=True, frozen=True)
-class Marktteilehmer(Geschaeftspartner, jsons.JsonSerializable):
+@attr.s(auto_attribs=True, kw_only=True)
+class Marktteilnehmer(Geschaeftspartner, jsons.JsonSerializable):
     """
     Objekt zur Aufnahme der Information zu einem Marktteilnehmer
     """
