@@ -4,7 +4,7 @@ import jsons
 from bo4e.com.com import COM
 
 
-@attr.s(auto_attribs=True, kw_only=True, frozen=True)
+@attr.s(auto_attribs=True, kw_only=True)
 class Katasteradresse(COM, jsons.JsonSerializable):
     """
     Dient der Adressierung über die Liegenschafts-Information.
